==> ecs-1.122.0-sources.jar: software/amazon/awscdk/services/ecs/EcsOptimizedAmi.java <==
package software.amazon.awscdk.services.ecs;

/**
 * (deprecated) Construct a Linux or Windows machine image from the latest ECS Optimized AMI published in SSM.
 * <p>
 * @deprecated see {@link EcsOptimizedImage#amazonLinux}, {@link EcsOptimizedImage#amazonLinux} and {@link EcsOptimizedImage#windows}
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.34.0 (build 9b72778)", date = "2021-09-08T20:44:44.494Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.EcsOptimizedAmi")
public class EcsOptimizedAmi extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.IMachineImage {

    protected EcsOptimizedAmi(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected EcsOptimizedAmi(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (deprecated) Constructs a new instance of the EcsOptimizedAmi class.
     * <p>
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public EcsOptimizedAmi(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.EcsOptimizedAmiProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { props });
    }

    /**
     * (deprecated) Constructs a new instance of the EcsOptimizedAmi class.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public EcsOptimizedAmi() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * (deprecated) Return the correct image.
     * <p>
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.MachineImageConfig getImage(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope) {
        return software.amazon.jsii.Kernel.call(this, "getImage", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.MachineImageConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
    }

    /**
     * (deprecated) A fluent builder for {@link software.amazon.awscdk.services.ecs.EcsOptimizedAmi}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.ecs.EcsOptimizedAmi> {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public static Builder create() {
            return new Builder();
        }

        private software.amazon.awscdk.services.ecs.EcsOptimizedAmiProps.Builder props;

        private Builder() {
        }

        /**
         * (deprecated) The Amazon Linux generation to use.
         * <p>
         * Default: AmazonLinuxGeneration.AmazonLinux2
         * <p>
         * @return {@code this}
         * @param generation The Amazon Linux generation to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder generation(final software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation) {
            this.props().generation(generation);
            return this;
        }

        /**
         * (deprecated) The ECS-optimized AMI variant to use.
         * <p>
         * Default: AmiHardwareType.Standard
         * <p>
         * @return {@code this}
         * @param hardwareType The ECS-optimized AMI variant to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder hardwareType(final software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType) {
            this.props().hardwareType(hardwareType);
            return this;
        }

        /**
         * (deprecated) The Windows Server version to use.
         * <p>
         * Default: none, uses Linux generation
         * <p>
         * @return {@code this}
         * @param windowsVersion The Windows Server version to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder windowsVersion(final software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion) {
            this.props().windowsVersion(windowsVersion);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.ecs.EcsOptimizedAmi}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public software.amazon.awscdk.services.ecs.EcsOptimizedAmi build() {
            return new software.amazon.awscdk.services.ecs.EcsOptimizedAmi(
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.ecs.EcsOptimizedAmiProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.ecs.EcsOptimizedAmiProps.Builder();
            }
            return this.props;
        }
    }
}

==> ecs-1.173.0-sources.jar: software/amazon/awscdk/services/ecs/EcsOptimizedAmi.java <==
package software.amazon.awscdk.services.ecs;

/**
 * (deprecated) Construct a Linux or Windows machine image from the latest ECS Optimized AMI published in SSM.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * Vpc vpc;
 * ComputeEnvironment myComputeEnv = ComputeEnvironment.Builder.create(this, "ComputeEnv")
 *         .computeResources(ComputeResources.builder()
 *                 .image(EcsOptimizedAmi.Builder.create()
 *                         .generation(AmazonLinuxGeneration.AMAZON_LINUX_2)
 *                         .build())
 *                 .vpc(vpc)
 *                 .build())
 *         .build();
 * </pre></blockquote>
 * <p>
 * @deprecated see {@link EcsOptimizedImage#amazonLinux}, {@link EcsOptimizedImage#amazonLinux} and {@link EcsOptimizedImage#windows}
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:35.792Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
@Deprecated
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.EcsOptimizedAmi")
public class EcsOptimizedAmi extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.IMachineImage {

    protected EcsOptimizedAmi(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected EcsOptimizedAmi(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (deprecated) Constructs a new instance of the EcsOptimizedAmi class.
     * <p>
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public EcsOptimizedAmi(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.EcsOptimizedAmiProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { props });
    }

    /**
     * (deprecated) Constructs a new instance of the EcsOptimizedAmi class.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public EcsOptimizedAmi() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * (deprecated) Return the correct image.
     * <p>
     * @param scope This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    @Override
    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ec2.MachineImageConfig getImage(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope) {
        return software.amazon.jsii.Kernel.call(this, "getImage", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.MachineImageConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required") });
    }

    /**
     * (deprecated) A fluent builder for {@link software.amazon.awscdk.services.ecs.EcsOptimizedAmi}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
    @Deprecated
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.ecs.EcsOptimizedAmi> {
        /**
         * @return a new instance of {@link Builder}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public static Builder create() {
            return new Builder();
        }

        private software.amazon.awscdk.services.ecs.EcsOptimizedAmiProps.Builder props;

        private Builder() {
        }

        /**
         * (deprecated) Whether the AMI ID is cached to be stable between deployments.
         * <p>
         * By default, the newest image is used on each deployment. This will cause
         * instances to be replaced whenever a new version is released, and may cause
         * downtime if there aren't enough running instances in the AutoScalingGroup
         * to reschedule the tasks on.
         * <p>
         * If set to true, the AMI ID will be cached in <code>cdk.context.json</code> and the
         * same value will be used on future runs. Your instances will not be replaced
         * but your AMI version will grow old over time. To refresh the AMI lookup,
         * you will have to evict the value from the cache using the <code>cdk context</code>
         * command. See https://docs.aws.amazon.com/cdk/latest/guide/context.html for
         * more information.
         * <p>
         * Can not be set to <code>true</code> in environment-agnostic stacks.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param cachedInContext Whether the AMI ID is cached to be stable between deployments. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder cachedInContext(final java.lang.Boolean cachedInContext) {
            this.props().cachedInContext(cachedInContext);
            return this;
        }

        /**
         * (deprecated) The Amazon Linux generation to use.
         * <p>
         * Default: AmazonLinuxGeneration.AmazonLinux2
         * <p>
         * @return {@code this}
         * @param generation The Amazon Linux generation to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder generation(final software.amazon.awscdk.services.ec2.AmazonLinuxGeneration generation) {
            this.props().generation(generation);
            return this;
        }

        /**
         * (deprecated) The ECS-optimized AMI variant to use.
         * <p>
         * Default: AmiHardwareType.Standard
         * <p>
         * @return {@code this}
         * @param hardwareType The ECS-optimized AMI variant to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder hardwareType(final software.amazon.awscdk.services.ecs.AmiHardwareType hardwareType) {
            this.props().hardwareType(hardwareType);
            return this;
        }

        /**
         * (deprecated) The Windows Server version to use.
         * <p>
         * Default: none, uses Linux generation
         * <p>
         * @return {@code this}
         * @param windowsVersion The Windows Server version to use. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        public Builder windowsVersion(final software.amazon.awscdk.services.ecs.WindowsOptimizedVersion windowsVersion) {
            this.props().windowsVersion(windowsVersion);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.ecs.EcsOptimizedAmi}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Deprecated)
        @Deprecated
        @Override
        public software.amazon.awscdk.services.ecs.EcsOptimizedAmi build() {
            return new software.amazon.awscdk.services.ecs.EcsOptimizedAmi(
                this.props != null ? this.props.build() : null
            );
        }

        private software.amazon.awscdk.services.ecs.EcsOptimizedAmiProps.Builder props() {
            if (this.props == null) {
                this.props = new software.amazon.awscdk.services.ecs.EcsOptimizedAmiProps.Builder();
            }
            return this.props;
        }
    }
}
